@@ -3,7 +3,7 @@ function (noflevels, input.combs) {
     if (!is.matrix(input.combs)) {
         if (!is.vector(input.combs)) {
             cat("\n")
-            stop("Input.combs must be either a base 3 matrix or a vector of line numbers.\n\n",
+            stop("input.combs must be either a base 3 matrix or a vector of line numbers.\n\n",
                  call. = FALSE)
             }
         else {
@@ -15,7 +15,7 @@ function (noflevels, input.combs) {
             input.combs <- getRow(noflevels + 1, input.combs)
             }
         }
-    mbase <- c(rev(cumprod(rev(noflevels + 1))), 1)[-1]
+    mbase <- rev(c(1, cumprod(rev(noflevels + 1))))[-1]
     allcombn <- t(createMatrix(noflevels)[-1, ])
     unique(as.vector(apply(input.combs, 1, function(x) (x*mbase) %*% allcombn + 1)))
     }
